# swiftest.save(**kwargs)
| Key Word Name   | Key Word Description                                                                                  | Options                                    |
|-----------------|-------------------------------------------------------------------------------------------------------|--------------------------------------------|
|```codename```   | Name of the N-body code to use. Default is ```Swiftest```.                                            | ```Swiftest```, ```Swifter```, ```Swift```  
|```param_file``` | Alternative name of the parameter input file.                                                         | string (ex. ```myparam.in```)  
|```param```      | Alternative parameter dictionary.                                                                     | dictionary  
|```framenum```   | Time frame from which to generate initial conditions. Default is -1 or the last frame in the dataset. | integer (ex. ```10```)  